
0.4.6 (2016-06-27)
##################

Changes since 0.4.5 (2016-04-01).

Bug Fixes
$$$$$$$$$

* fixes `#308 <https://github.com/biocommons/hgvs/issues/308/>`_: fix issues with validating across CDS start and CDS end boundaries [`BROKEN: ce6995941984 <https://github.com/biocommons/hgvs/commit/ce6995941984>`_]

Other Changes
$$$$$$$$$$$$$

* closes `#309 <https://github.com/biocommons/hgvs/issues/309/>`_: make errors more informative when coordinate is outside sequence bounds [`BROKEN: e6e0decdad8e <https://github.com/biocommons/hgvs/commit/e6e0decdad8e>`_]
* closes `#295 <https://github.com/biocommons/hgvs/issues/295/>`_: raise error when attempting to validate del length in intronic variants [`BROKEN: 13674d3c6d14 <https://github.com/biocommons/hgvs/commit/13674d3c6d14>`_]

Internal and Developer Changes
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

* fix issues with release docs for 0.4.x layout [`BROKEN: 52b2358fed02 <https://github.com/biocommons/hgvs/commit/52b2358fed02>`_]
